
;-------------------------------------------------------------------------------------------------------------
;- Structures
;-------------------------------------------------------------------------------------------------------------

Structure MainWindow; Main Window Information
  x.l; the x position of the window
  y.l; the y position of the window
  w.l; the width ofthe window
  h.l; the height of hte window
  sStr.s; the window title (string)
  lOps.l; the operands / paramaters for opening the window
EndStructure;
Define Wnd.MainWindow;

Structure GameInformation; Information relevant to the game itself
  px.l; players x position on screen
  py.l; players y position on the screen
  pdir.l; players direction (0=left 1=right 2=up 3=down)
  lanim.l; the position through the sprite animation the player is at
  gMode.l; The game mode (0 = StartupScreen 1=file select 2=ingamehouse 3=ingameoutside 4=ingamedungeon
  lx.l; the levels x position on the screen
  ly.l; the levels y position on the screen
  lType.l; the level type (0=house 1=outside 2=dungeon)
  lbgcol.l; the levels default background colour
  sLevel.s; the name of the level
  sUsername.s; the name of the current player / user
  
  lHeartsGot.l; how many hearts the person has in total
  lHeartHealth.l; the players health
  lHealthMax.l; the maximum possible health for the player
  lMagicQty.l; how much magic is left (-1 = no magic bar)
  lRupeeQty.l; how many rupees the player has
  
  lMenuTimer.l; the timer for the menu;
  lMenuOpen.l; is the menu opened or closed? open=1 closed=0
  lMenuOption.l; the place the menu selector is at
  lItemSet.l; the item set to be used
  
  lGotSword.l; has the player got the sword?
  lSwordAway.l; is the sword away or out? away=1 out=0;howsu?
  lGotBoomerang.l; has got the boomerang?
  lGotLense.l; has the player got the lense?
  lGotShield.l; has the player got the sheild?
  lGotHBoots.l; has the player got the hover boots?
  lGotBow.l; has the player got the bow and arrow?
  lGotBombs.l; has the player got the bombs?
EndStructure;
Global GInfo.GameInformation;

Structure GameObjects;; The Objects in each level
  ox.l; the objects x position on the screen
  oy.l; the objects y position on the screen
  type.l; the objects type ( 0=door 1=level transition 2=npc 3=walking npc 4=textbox 5=bat 6=octork ADD MORE)
  mask.l; the objects image mask
  limg1.l; image 1
  limg2.l;       2
  limg3.l;       3
  sText.s; Text of the object
  sString.s;any string relevant to the object
EndStructure;
Global NewList GObjects.GameObjects();

; startup
Declare LoadStartupSprites();
Declare DestroyStartupSprites();
Declare DisplayStartupSprites();
Declare LoadStartupVariables();
Declare StartupKeyboardInput();

;ingame
Declare LoadInGameSprites();
Declare DisplayInGameSprites();
Declare LoadInGameVariables();
Declare InGameKeyboardInput();

Declare LoadSprites();
Declare DisplaySprites();
Declare LoadVariables();
Declare KeyBoardInput();

Declare LoadPlayerSpritesWalkLeft();
Declare LoadPlayerSpritesWalkRight();
Declare LoadPlayerSpritesWalkUp();
Declare LoadPlayerSpritesWalkDown();
Declare LoadPlayerSprites();

Declare DisplayPlayerSprites();

;playeractinos
Declare PlayerWalkLeftHouse();
Declare PlayerWalkRightHouse();
Declare PlayerWalkUpHouse();
Declare PlayerWalkDownHouse();
Declare PlayerWalking();
Declare PlayerCollisionCheck(x.l,y.l,lx.l,ly.l);

;levels
Declare LoadLevel(sLevel.s);
Declare DisplayLevelBG();
Declare DisplayLevelFG();

;hud
Declare LoadHUDSprites();
Declare DisplayHUD();

;heartengine
Declare LoadHeartSprites();
Declare DisplayHeartSprites();
Declare AddHealth();

;magicengine
Declare LoadMagicSprites();
Declare DisplayMagicSprites();
Declare AddMagic(ladd.l);

;rupeeengine
Declare LoadRupeeSprites();
Declare DisplayRupeeSprites();
Declare AddRupee(ladd.l);

;menuengine
Declare LoadMenuSprites();
Declare DisplayMenuSprites();
Declare DisplayMenuItems();
Declare DisplayHUDItems();
Declare DisplayMenuSelector();
Declare MenuKeyboardInput();
Declare KeyBoardMenuOpenClose();
Declare KeyBoardMenuSelector();

;objectengine
Declare LoadObjects(sLevel.s);
Declare DisplayObjects();
Declare CheckObjectCollision(x.l,y.l);


;-------------------------------------------------------------------------------------------------------------
;- Imagery
;-------------------------------------------------------------------------------------------------------------
; Essential Main Game Procedures
UsePNGImageDecoder(); Use the png image decoder for the sprites
InitSprite(); initialise the sprite environment
InitKeyboard(); initialise the keybaord input encironment

LoadFont(0,"Tahoma",7);the default ingame font

Enumeration; Sprites
; Startup
  #sprStartLogo; the games logo
  #sprStartBackground; the background image for the game
  
; InGame
  ; Player
  #sprPMask;
  #sprPLeft0;
  #sprPLeft1;
  #sprPLeft2;
  #sprPLeft3;
  #sprPLeft4;
  #sprPLeft5;
  #sprPLeft6;
  #sprPLeft7;
  
  #sprPRight0;
  #sprPRight1;
  #sprPRight2;
  #sprPRight3;
  #sprPRight4;
  #sprPRight5;
  #sprPRight6;
  #sprPRight7;
  
  #sprPUp0;
  #sprPUp1;
  #sprPUp2;
  #sprPUp3;
  #sprPUp4;
  #sprPUp5;
  #sprPUp6;
  #sprPUp7;
  
  #sprPDown0;
  #sprPDown1;
  #sprPDown2;
  #sprPDown3;
  #sprPDown4;
  #sprPDown5;
  #sprPDown6;
  #sprPDown7;
  
  ; Level
  #sprLMask;
  #sprLbg;
  #sprLfg;
  
  ; HUD
  #sprHUDhearthold;
    #sprHeart0;
    #sprHeart1;
    #sprHeart2;
    #sprHeart3;
    #sprHeart4;
  #sprHUDmagichold;
  #sprHUDitemhold;
    #sprMenuSword;
    #sprMenuSwordAway;
    #sprMenuBoomerang;
    #sprMenuLense;
    #sprMenuShield;
    #sprMenuBoots;
    #sprMenuBow;
    #sprMenuBomb;
  #sprMainMenu;
    #sprMenuSel1;
    #sprMenuSel2;
  #sprHUDrupeehold;
  #sprHUDkeyhold;
  
; Other
  #sprLastSprite;
EndEnumeration;

Global lLastSpr.l=#sprLastSprite;




;-------------------------------------------------------------------------------------------------------------
;- Procedures
;-------------------------------------------------------------------------------------------------------------
Procedure LoadSprites(); Procedure to load the sprites required for the game
  If GInfo\gMode=0; If the gamemode is set to the Startup Screen
    LoadStartupSprites();
  ElseIf GInfo\gMode=1; File Select Screen
  
  ElseIf GInfo\gMode=2; Ingame
    LoadInGameSprites();
  EndIf;
EndProcedure;

Procedure DisplaySprites(); Procedure to load the sprites required for the game
  If GInfo\gMode=0; If the gamemode is set to the Startup Screen
    DisplayStartupSprites();
  ElseIf GInfo\gMode=1; File Select Screen
  
  ElseIf GInfo\gMode=2; Ingame
    DisplayInGameSprites();
  EndIf;
EndProcedure;

Procedure LoadVariables(); Procedure to load all of the game variables
  If GInfo\gMode=0; If the gamemode is set to the Startup Screen
    LoadStartupVariables();
  ElseIf GInfo\gMode=1; File Select Screen
  
  ElseIf GInfo\gMode=2; Ingame
    If OpenPreferences("Savedata.prefs");
      GInfo\sUsername=ReadPreferenceString("Last User","Link");
    EndIf
    LoadInGameVariables();
  EndIf;
EndProcedure;

Procedure KeyBoardInput(); Procedure to check for keyboard input
  ExamineKeyboard();
  If GInfo\gMode=0; If the gamemode is set to the Startup Screen
    StartupKeyboardInput();
  ElseIf GInfo\gMode=1; File Select Screen
  
  ElseIf GInfo\gMode=2; Ingame
    InGameKeyboardInput();
  EndIf;
EndProcedure;

; IDE Options = PureBasic v4.02 (Windows - x86)
; CursorPosition = 130
; FirstLine = 109
; Folding = w
; UseMainFile = game.pb
; IDE Options = PureBasic v4.02 (Windows - x86)
; CursorPosition = 58
; FirstLine = 33
; Folding = 4